@@ -1,7 +1,7 @@
 
-## generate Lotka-Volterra monte-carlo sample data ------------------
+## generate Lotka-Volterra with monte-carlo simulations sample data ------
 
-## generate equations -----------------------------------------------
+## generate equations ----------------------------------------------------
 
 # X=Pred,Y=Prey
 
@@ -13,24 +13,24 @@ equations <- c(eq_X,eq_Y)
 names(equations) <- vars
 x0 <- c(0.9,0.9)
 names(x0) <- vars
-theta <- c(2/3,4/3,1,1)
+theta <- c(2/3,4/3,2,1)
 names(theta) <- pars
 
 # generate monte-carlo observations  -------------------------------------
 
 library("simode")
-N <- 100
-time <- seq(0,25,length.out=N)
+n <- 100
+time <- seq(0,25,length.out=n)
 model_out <- solve_ode(equations,theta,x0,time)
 x_det <- model_out[,vars]
-mc_sets <- 10
+N <- 5
 set.seed(1000)
 sigma <- 0.1
 mc_obs <- list()
-for(j in 1:mc_sets) {
+for(j in 1:N) {
   obs <- list()
   for(i in 1:length(vars)) {
-    obs[[i]] <- pmax(0, rnorm(N,x_det[,i],sigma))
+    obs[[i]] <- rnorm(n,x_det[,i],sigma)
   }
   names(obs) <- vars
   mc_obs[[j]] <- obs
@@ -40,9 +40,9 @@ for(j in 1:mc_sets) {
 
 simode_fits <- simode(
   equations=equations, pars=c(pars,vars), time=time, obs=mc_obs,
-  mc_sets=mc_sets, simode_ctrl=simode.control(parallel=T,save_to_log=T))
+  obs_sets=N, simode_ctrl=simode.control(trace=1,parallel=T,save_to_log=T))
 
-summary(simode_fits,pars_true=c(theta[pars],x0))
+summary(simode_fits,sum_mean_sd=T,pars_true=c(theta[pars],x0),digits=2)
+plot(simode_fits, type='fit', plot_mean_sd=T, pars_true=c(theta,x0), mfrow=c(2,1), legend=T)
+plot(simode_fits, type='est', show='both', plot_mean_sd=T, pars_true=c(theta,x0), legend=T)
 
-plot(simode_fits, type='fit', pars_true=c(theta,x0), mfrow=c(2,1),legend=T)
-plot(simode_fits, type='est', show='both', pars_true=c(theta,x0), legend=T)
